==> snaptoolbelt-0.14.0-py2-none-any.whl: snaptoolbelt/network.py <==
"""SNAPtoolbelt Mesh/Network Commands"""
from __future__ import print_function

import logging
import os

from argparse import RawDescriptionHelpFormatter
from textwrap import dedent

import progressbar

from arghandler import ArgumentHandler

from snap_profile.network import Network

import snapstraction.mesh
import snapstraction.node_finder

log = logging.getLogger(__name__)


def network(parser, context, args):
    """Network-related subcommands"""
    handler = ArgumentHandler(
        usage="snap [global options] network [-h] (dm-ping|intercept|listen|ping|topology) [options]",
        description=dedent("""
        SNAP Network Commands:
          dm-ping: Ping the network, use directed multicast RPC for replies
          intercept: Listen for intercepted node output
          listen: Listen for all traffic
          ping: Ping the network, use unicast RPC for replies
          topology: Acquire the topology of the network
        """),
        formatter_class=RawDescriptionHelpFormatter,
    )

    handler.set_subcommands({
        'dm-ping': dm_ping,
        'intercept': intercept_listen,
        'listen': listen,
        'ping': ping,
        'topology': topology,
    })

    handler.run(args, context_fxn=lambda x: context)


def ping(parser, context, args):
    """Ping the network"""
    handler = ArgumentHandler(
        usage="snap [global options] network ping [-h] [--timeout <seconds>]",
        description="Ping the network looking for nearby nodes, use unicast RPC for replies",
    )

    handler.add_argument(
        "-t",
        "--timeout",
        default=20,
        type=int,
        help="Time to wait for responses",
    )

    args, rest = handler.parse_known_args(args)

    if rest:
        log.error("Unexpected arguments to network ping command: %r", rest)
        exit(1)

    log.info("Ping the network")

    widgets = [progressbar.FormatLabel('Unicast Ping'), ' ',
               progressbar.FormatLabel('Found 0 ()'), ' ',
               progressbar.Percentage(), ' ', progressbar.Bar(), ' ',
               progressbar.Timer(), ' ', progressbar.AdaptiveETA()]

    progress = progressbar.ProgressBar(widgets=widgets, maxval=args.timeout)
    progress.start()

    def on_progress(seconds, found_count, last_addr):
        """Update progress bar"""
        widgets[2] = progressbar.FormatLabel('Found %d (%s)' %
                                             (found_count, last_addr))
        progress.update(seconds)

    def on_finished():
        """Finish progress bar"""
        progress.finish()

    with context.gus() as gus:
        result = gus.run_sync(args.timeout + 1,
                              snapstraction.mesh.unicast_ping,
                              args.timeout,
                              context.output,
                              progress_cb=on_progress,
                              finished_cb=on_finished)
        context.output(result)


def dm_ping(parser, context, args):
    """Ping that uses dmcast for the response instead of unicast"""
    handler = ArgumentHandler(
        usage="snap [global options] network dm-ping [-h] [--timeout <seconds>]",
        description="Ping the network looking for nearby nodes, use directed multicast for replies",
    )

    handler.add_argument(
        "-t",
        "--timeout",
        default=20,
        type=int,
        help="Time to wait for responses",
    )

    args, rest = handler.parse_known_args(args)

    if rest:
        log.error("Unexpected arguments to network dm-ping command: %r", rest)
        exit(1)

    log.info("Ping the network")

    widgets = [progressbar.FormatLabel('Directed Multicast Ping'), ' ',
               progressbar.FormatLabel('Found 0 ()'), ' ',
               progressbar.Percentage(), ' ', progressbar.Bar(), ' ',
               progressbar.Timer(), ' ', progressbar.AdaptiveETA()]

    progress = progressbar.ProgressBar(widgets=widgets, maxval=args.timeout)
    progress.start()

    def on_progress(seconds, found_count, last_addr):
        """Update progress bar"""
        widgets[2] = progressbar.FormatLabel('Found %d (%s)' %
                                             (found_count, last_addr))
        progress.update(seconds)

    def on_finished():
        """Finish progress bar"""
        progress.finish()

    with context.gus() as gus:
        result = gus.run_sync(args.timeout + 1,
                              snapstraction.mesh.dmcast_ping,
                              args.timeout,
                              context.output,
                              progress_cb=on_progress,
                              finished_cb=on_finished)
        context.output(result)


def intercept_listen(parser, context, args):
    """Listen for intercepted node output"""
    handler = ArgumentHandler(
        usage="snap [global options] network intercept [-h] [--timeout <seconds>]",
        description="Listen for intercepted node output",
    )

    handler.add_argument(
        '-t',
        '--timeout',
        type=int,
        default=None,
        help='How many seconds to listen (default: forever)',
    )

    args, rest = handler.parse_known_args(args)

    if rest:
        log.error("Unexpected arguments to network intercept command: %r", rest)
        exit(1)

    log.info("Trying to listen for intercepted output")

    with context.gus() as gus:
        gus.run_sync(None,
                     snapstraction.mesh.listen_for_intercepted_output,
                     context.output,
                     _timeout=args.timeout)


def find(parser, context, args):
    """find the target node"""
    handler = ArgumentHandler(
        usage="snap [global options] find [-h] <target(s)> [--list <list-file>] [--move <network>]",
        description="Find the target node(s), optionally moving them to the specified network",
    )

    handler.add_argument(
        'targets',
        nargs='?',
        default=None,
        help="Node(s) to find",
    )

    handler.add_argument(
        '-l',
        '--list',
        dest="list_file",
        help="File containing list of nodes to find",
    )

    handler.add_argument(
        '-m',
        '--move',
        help="Profile to move nodes to.",
    )

    args, rest = handler.parse_known_args(args)

    if rest:
        log.error("Unexpected arguments to find command: %r", rest)
        exit(1)

    if args.list_file:
        # do expansion of list file name/path
        list_file_path = os.path.join(os.path.curdir, os.path.expanduser(args.list_file))
        targets = snapstraction.node_finder.get_targets_from_file(list_file_path)
    elif args.targets:
        targets = args.targets.split(',')
    else:
        log.error("Must provide either comma-separated target addresses (123456,234567,...) or a file with a list of targets, one per line")
        raise Exception("No targets provided")

    # load the network data to pass down
    move_to_network = Network.load(args.move) if args.move else None

    log.info("finding node(s), optionally moving to target network...")

    with context.gus() as gus:
        result = gus.run_sync(context.timeout, snapstraction.node_finder.finder,
                              targets, move_to_network=move_to_network)
        context.output(result)


def topology(parser, context, args):
    """Take the topology of the network"""
    handler = ArgumentHandler(
        usage="snap [global options] network topology [-h]",
        description="Gather the topology of the network",
    )

    args, rest = handler.parse_known_args(args)

    if rest:
        log.error("Unexpected arguments to network topology command: %r", rest)
        exit(1)

    log.info("Get the topology of the network")

    with context.gus() as gus:
        result = gus.run_sync(context.timeout,
                              snapstraction.mesh.poll_topology)
        context.output(result)


def listen(parser, context, args):
    """Listen to packets received"""
    handler = ArgumentHandler(
        usage="snap [global options] network listen [-h] [--timeout <seconds>]",
        description="Listen for all traffic",
    )

    handler.add_argument(
        '-t',
        '--timeout',
        type=int,
        default=None,
        help='How many seconds to listen (default: forever)'
    )

    args, rest = handler.parse_known_args(args)

    if rest:
        log.error("Unexpected arguments to network listen command: %r", rest)
        exit(1)

    log.info("Listening to the network")

    with context.gus() as gus:
        gus.run_sync(None,
                     snapstraction.mesh.listen,
                     context.output,
                     _timeout=args.timeout)

==> snaptoolbelt-1.0.1-py2-none-any.whl: snaptoolbelt/network.py <==
"""SNAPtoolbelt Mesh/Network Commands"""
from __future__ import print_function

import logging
import os

from argparse import RawDescriptionHelpFormatter
from textwrap import dedent

import progressbar

from arghandler import ArgumentHandler

from snap_profile.network import Network

import snapstraction.mesh
import snapstraction.node_finder
import snapstraction.topology

import topology_utils

log = logging.getLogger(__name__)


def network(parser, context, args):
    """Network-related subcommands"""
    handler = ArgumentHandler(
        usage="snap [global options] network [-h] (dm-ping|intercept|listen|ping|topology) [options]",
        description=dedent("""
        SNAP Network Commands:
          dm-ping: Ping the network, use directed multicast RPC for replies
          intercept: Listen for intercepted node output
          listen: Listen for all traffic
          ping: Ping the network, use unicast RPC for replies
          topology: Acquire the topology of the network
        """),
        formatter_class=RawDescriptionHelpFormatter,
    )

    handler.set_subcommands({
        'dm-ping': dm_ping,
        'intercept': intercept_listen,
        'listen': listen,
        'ping': ping,
        'topology': topology,
    })

    handler.run(args, context_fxn=lambda x: context)


def ping(parser, context, args):
    """Ping the network"""
    handler = ArgumentHandler(
        usage="snap [global options] network ping [-h] [-c <count>] [-t <ttl>]",
        description="Ping the network looking for nearby nodes, use unicast RPC for replies",
    )

    handler.add_argument(
        "-c",
        "--count",
        default=3,
        type=int,
        help="# of packets to send (default is 3)",
    )

    handler.add_argument(
        "-t",
        "--ttl",
        default=5,
        type=int,
        help="Multicast TTL for pings (default is 5)",
    )

    args, rest = handler.parse_known_args(args)

    if rest:
        log.error("Unexpected arguments to network ping command: %r", rest)
        exit(1)

    log.info("Ping the network")

    widgets = [progressbar.FormatLabel('Unicast Ping'), ' ',
               progressbar.FormatLabel('Found 0 ()'), ' ',
               progressbar.Percentage(), ' ', progressbar.Bar(), ' ',
               progressbar.Timer(), ' ', progressbar.AdaptiveETA()]

    progress = progressbar.ProgressBar(widgets=widgets, maxval=args.count)
    progress.start()

    def on_progress(seconds, found_count, last_addr):
        """Update progress bar"""
        widgets[2] = progressbar.FormatLabel('Found %d (%s)' %
                                             (found_count, last_addr))
        progress.update(seconds)

    def on_finished():
        """Finish progress bar"""
        progress.finish()

    with context.gus() as gus:
        result = gus.run_sync(args.count + 1,
                              snapstraction.mesh.unicast_ping,
                              count=args.count,  # We ping each second
                              ttl=args.ttl,
                              progress_cb=on_progress,
                              finished_cb=on_finished)
        context.output(result)


def dm_ping(parser, context, args):
    """Ping that uses dmcast for the response instead of unicast"""
    handler = ArgumentHandler(
        usage="snap [global options] network dm-ping [-h] [-c <count>] [-t <ttl>]",
        description="Ping the network looking for nearby nodes, use directed multicast for replies",
    )

    handler.add_argument(
        "-c",
        "--count",
        default=3,
        type=int,
        help="# of packets to send (default is 3)",
    )

    handler.add_argument(
        "-t",
        "--ttl",
        default=5,
        type=int,
        help="Multicast TTL for pings (default is 5)",
    )

    args, rest = handler.parse_known_args(args)

    if rest:
        log.error("Unexpected arguments to network dm-ping command: %r", rest)
        exit(1)

    log.info("Ping the network")

    widgets = [progressbar.FormatLabel('Directed Multicast Ping'), ' ',
               progressbar.FormatLabel('Found 0 ()'), ' ',
               progressbar.Percentage(), ' ', progressbar.Bar(), ' ',
               progressbar.Timer(), ' ', progressbar.AdaptiveETA()]

    progress = progressbar.ProgressBar(widgets=widgets, maxval=args.count)
    progress.start()

    def on_progress(seconds, found_count, last_addr):
        """Update progress bar"""
        widgets[2] = progressbar.FormatLabel('Found %d (%s)' %
                                             (found_count, last_addr))
        progress.update(seconds)

    def on_finished():
        """Finish progress bar"""
        progress.finish()

    with context.gus() as gus:
        result = gus.run_sync(args.count + 1,
                              snapstraction.mesh.dmcast_ping,
                              count=args.count,  # We ping each second
                              ttl=args.ttl,
                              progress_cb=on_progress,
                              finished_cb=on_finished)
        context.output(result)


def intercept_listen(parser, context, args):
    """Listen for intercepted node output"""
    handler = ArgumentHandler(
        usage="snap [global options] network intercept [-h] [--timeout <seconds>]",
        description="Listen for intercepted node output",
    )

    handler.add_argument(
        '-t',
        '--timeout',
        type=int,
        default=None,
        help='How many seconds to listen (default: forever)',
    )

    args, rest = handler.parse_known_args(args)

    if rest:
        log.error("Unexpected arguments to network intercept command: %r", rest)
        exit(1)

    log.info("Trying to listen for intercepted output")

    with context.gus() as gus:
        gus.run_sync(None,
                     snapstraction.mesh.listen_for_intercepted_output,
                     context.output,
                     _timeout=args.timeout)


def find(parser, context, args):
    """find the target node"""
    handler = ArgumentHandler(
        usage="snap [global options] find [-h] <target(s)> [--list <list-file>] [--move <network>]",
        description="Find the target node(s), optionally moving them to the specified network",
    )

    handler.add_argument(
        'targets',
        nargs='?',
        default=None,
        help="Node(s) to find",
    )

    handler.add_argument(
        '-l',
        '--list',
        dest="list_file",
        help="File containing list of nodes to find",
    )

    handler.add_argument(
        '-m',
        '--move',
        help="Profile to move nodes to.",
    )

    args, rest = handler.parse_known_args(args)

    if rest:
        log.error("Unexpected arguments to find command: %r", rest)
        exit(1)

    if args.list_file:
        # do expansion of list file name/path
        list_file_path = os.path.join(os.path.curdir, os.path.expanduser(args.list_file))
        targets = snapstraction.node_finder.get_targets_from_file(list_file_path)
    elif args.targets:
        targets = args.targets.split(',')
    else:
        log.error("Must provide either comma-separated target addresses (123456,234567,...) or a file with a list of targets, one per line")
        raise Exception("No targets provided")

    # load the network data to pass down
    move_to_network = Network.load(args.move) if args.move else None

    log.info("finding node(s), optionally moving to target network...")

    with context.gus() as gus:
        result = gus.run_sync(context.timeout, snapstraction.node_finder.finder,
                              targets, move_to_network=move_to_network)
        context.output(result)


def topology(parser, context, args):
    """Take the topology of the network"""
    handler = ArgumentHandler(
        usage="snap [global options] network topology [-h] <root node> [-d [-c]] [-s]",
        description="Gather the topology of the network, starting at the root (defaults to the bridge)",
    )

    handler.add_argument(
        "root_node",
        nargs="?",
        default="bridge",
        help="Root of topology (starting point)",
    )

    handler.add_argument(
        "-d",
        "--dot",
        help="Output DOT digraph format",
        action="store_true",
    )

    handler.add_argument(
        "-c",
        "--colorize-lq",
        help="Colorize edges based on link quality. (>-30 dBm is excellent, <-80 dBm is bad.)",
        action="store_true",
    )

    handler.add_argument(
        "-s",
        "--simplify",
        help="Merge digraph into undirected graph format",
        action="store_true",
    )

    args, rest = handler.parse_known_args(args)

    if rest:
        log.error("Unexpected arguments to network topology command: %r", rest)
        exit(1)

    log.info("Get the topology of the network")

    with context.gus() as gus:
        result = gus.run_sync(
            context.timeout,
            snapstraction.topology.take_network_census,
            args.root_node,
        )
        if args.simplify:
            result = topology_utils.simplify_topology(result)

        if args.dot:
            if args.simplify:
                func = topology_utils.render_as_dot_simple_graph
            else:
                func = topology_utils.render_as_dot_digraph

            for line in func(result, colorize_lq=args.colorize_lq):
                print(line)
        else:
            context.output(result['topology'])


def listen(parser, context, args):
    """Listen to packets received"""
    handler = ArgumentHandler(
        usage="snap [global options] network listen [-h] [--timeout <seconds>]",
        description="Listen for all traffic",
    )

    handler.add_argument(
        '-t',
        '--timeout',
        type=int,
        default=None,
        help='How many seconds to listen (default: forever)'
    )

    args, rest = handler.parse_known_args(args)

    if rest:
        log.error("Unexpected arguments to network listen command: %r", rest)
        exit(1)

    log.info("Listening to the network")

    with context.gus() as gus:
        gus.run_sync(None,
                     snapstraction.mesh.listen,
                     context.output,
                     _timeout=args.timeout)
